###############################################################################
# Makefile for any library
#
# Copyright (C) 2010 Nintendo.  All rights reserved.
#
# These coded instructions, statements, and computer programs contain
# proprietary information of Nintendo of America Inc. and/or Nintendo
# Company Ltd., and are protected by Federal copyright law.  They may
# not be disclosed to third parties or copied or duplicated in any form,
# in whole or in part, without the prior written consent of Nintendo.
#
###############################################################################

# NOTE: Only MODULE_DEPTH needs to be modified!

# This makefile must set the relative depth to the src directory
# using only "..", without a trailing slash

MODULE_DEPTH := ../../..
BUILD_MAKE_PATH := $(MODULE_DEPTH)/build/make

# commondefs must be included near the top so that all common variables
# will be defined before their use.  Define commondefs for compiler.

include $(BUILD_MAKE_PATH)/commondefs.mk
include $(BUILD_MAKE_PATH)/commondefs.iop.gcc.mk

# LIB := TRUE tells modulerules to treat this as a library, not as an executable
LIB := TRUE

# CLIBSRCS, CPPLIBSRCS, and ASMLIBSRCS automatically lists all
# C, C++, and assembly files that should be compiled and linked for the library
# Use a different suffix if you do not want the file to be compiled and linked.

# The name of the library is automatically set to the directory name of this module.
# The path to the library output is $(LIB_DIR)/$(LIBNAME)$(LIBSUFFIX)

# Define global includes here so we don't have to modify BroadOn's code (TODO: Fix this)
# Order of additional include path precedence: make sure global headers in module directory
# is before the global system/include directory.
# Convert to mixed mode for Codewarrior
GINCLUDES  := $(shell cygpath -m $(MODULE_DIR)/headers/cos/secure $(INCLUDE_DIR)/cos/secure)

CLIBSRCS =  mxml-attr.c \
            mxml-entity.c \
            mxml-file.c \
            mxml-index.c \
			mxml-node.c \
            mxml-search.c \
            mxml-set.c \
            mxml-private.c \
            mxml-string.c

OBJ_DIR = $(MODULE_DEPTH)/../obj/$(TOOLCHAIN)/$(PLATFORM)/$(MODULE_PATH_FROM_SRC)/$(BUILD_TARGET)
override LIBNAME = mxml
CCFLAGS += -w

###############################################################################
# modulerules contains the rules that will use the above variables
# and dependencies below to construct the binaries specified.
# Do not specify any targets before including modulerules.
include $(BUILD_MAKE_PATH)/modulerules.mk







#======== End of makefile ========#